==> sslcontext-kickstart-7.0.0-sources.jar: nl/altindag/ssl/hostnameverifier/BasicHostNameVerifier.java <==
/*
 * Copyright 2019-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.altindag.ssl.hostnameverifier;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLSession;

/**
 * <strong>NOTE:</strong>
 * Please don't use this class directly as it is part of the internal API. Class name and methods can be changed any time.
 * Instead use the {@link nl.altindag.ssl.util.HostnameVerifierUtils HostnameVerifierUtils} which provides the same functionality
 * while it has a stable API because it is part of the public API.
 * </p>
 *
 * @author Hakan Altindag
 */
public class BasicHostNameVerifier implements HostnameVerifier {

    private static final HostnameVerifier INSTANCE = new BasicHostNameVerifier();

    private BasicHostNameVerifier() {}

    @Override
    public boolean verify(String host, SSLSession sslSession) {
        return host.equalsIgnoreCase(sslSession.getPeerHost());
    }

    public static HostnameVerifier getInstance() {
        return INSTANCE;
    }

}

==> sslcontext-kickstart-7.2.1-sources.jar: nl/altindag/ssl/hostnameverifier/BasicHostNameVerifier.java <==
/*
 * Copyright 2019-2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.altindag.ssl.hostnameverifier;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLSession;

/**
 * <strong>NOTE:</strong>
 * Please don't use this class directly as it is part of the internal API. Class name and methods can be changed any time.
 * Instead use the {@link nl.altindag.ssl.util.HostnameVerifierUtils HostnameVerifierUtils} which provides the same functionality
 * while it has a stable API because it is part of the public API.
 * </p>
 *
 * @author Hakan Altindag
 */
public final class BasicHostNameVerifier implements HostnameVerifier {

    private static final HostnameVerifier INSTANCE = new BasicHostNameVerifier();

    private BasicHostNameVerifier() {}

    @Override
    public boolean verify(String host, SSLSession sslSession) {
        return host.equalsIgnoreCase(sslSession.getPeerHost());
    }

    public static HostnameVerifier getInstance() {
        return INSTANCE;
    }

}
